.. _api:

Scorched API
============

API
---

.. automodule:: scorched.connection
   :members: grouper

.. autoclass:: SolrConnection
   :members:

   .. automethod:: __init__

.. autoclass:: SolrInterface
   :members:

   .. automethod:: __init__
